Badges class

Predefined badge configurations matching common design patterns

Constructors

Badges()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

badge({required String text, Widget? leftWidget1, Widget? leftWidget2, Widget? rightWidget, bool removable = false, VoidCallback? onRemove, BadgeSize size = BadgeSize.md, Color backgroundColor = UiColors.neutral700, Color textColor = UiColors.onPrimary, Color? borderColor = UiColors.neutral300}) BaseBadge
Creates a default badge with dark background
checkbox({bool isChecked = false, ValueChanged<bool>? onChanged, double? size, Color? backgroundColor, Color? borderColor, Color? checkColor}) BaseCheckbox
Creates a checkbox for use in badges Uses the BaseCheckbox component with appropriate sizing for badges