DropdownOption<T> class

A selectable option in a dropdown menu

Constructors

const

Properties

builder Widget Function(BuildContext context, bool selected, bool focused)?
Custom builder for this option (overrides default rendering)
final
enabled bool
Whether this option is enabled
final
group String?
Optional group label for this item
final
hashCode int
The hash code for this object.
no setteroverride
icon Widget?
Optional icon to display before the label
final
label String
The display label for this option
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDivider bool
Optional divider below this item
final
supportingText String?
Optional supporting text below the label
final
trailing Widget?
Optional trailing widget (overrides checkmark for selected items)
final
value → T
The value associated with this option
final

Methods

copyWith({T? value, String? label, String? supportingText, Widget? icon, Widget? trailing, bool? enabled, bool? showDivider, String? group, Widget builder(BuildContext context, bool selected, bool focused)?}) DropdownOption<T>
Create a copy of this option with some fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override